Index: trunk/src/org/openstreetmap/josm/data/validation/tests/Addresses.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/validation/tests/Addresses.java	(revision 5747)
+++ trunk/src/org/openstreetmap/josm/data/validation/tests/Addresses.java	(revision 5748)
@@ -43,4 +43,5 @@
     protected static final String ADDR_HOUSE_NUMBER  = "addr:housenumber";
     protected static final String ADDR_INTERPOLATION = "addr:interpolation";
+    protected static final String ADDR_PLACE         = "addr:place";
     protected static final String ADDR_STREET        = "addr:street";
     protected static final String ASSOCIATED_STREET  = "associatedStreet";
@@ -85,6 +86,6 @@
     public void visit(Node n) {
         List<Relation> associatedStreets = getAndCheckAssociatedStreets(n);
-        // Find house number without street (neither addr:street or associatedStreet)
-        if (n.hasKey(ADDR_HOUSE_NUMBER) && !n.hasKey(ADDR_STREET)) {
+        // Find house number without proper location (neither addr:street, associatedStreet or addr:place)
+        if (n.hasKey(ADDR_HOUSE_NUMBER) && !n.hasKey(ADDR_STREET) && !n.hasKey(ADDR_PLACE)) {
             for (Relation r : associatedStreets) {
                 if (r.hasTag("type", ASSOCIATED_STREET)) {
